@@ -21,14 +21,6 @@ test_that("match_tables() returns only requested tables", {
   t3 <- test_match_tables("5368.0", c("1", "12a"))
   expect_length(t3, 2)
 
-
-  t4 <- test_match_tables("6401.0", "1")
-  expect_length(t4, 1)
-
-  t5 <- test_match_tables("6401.0", "2")
-  expect_length(t5, 1)
-  expect_identical(t5, t4) # Tables 1 and 2 are combined in 6401.0
-
   t6 <- test_match_tables("6291.0.55.001", "1")
   expect_length(t6, 1)
 
